@@ -99,6 +99,10 @@ def pythran_builtin_path(name):
 def pythran_builtin_attr(name):
     return path_to_attr(pythran_builtin_path(name))
 
+def cxxid(name):
+    from pythran.tables import cxx_keywords
+    return name + '_' * (name in cxx_keywords)
+
 
 @contextmanager
 def pushpop(l, v):
